<?php
/**
* 123kurier.sk - Functions
*/

if (!function_exists('zk123_sanitizePhoneNumber')) {

function zk123_sanitizePhoneNumber($s, $stat = 'SK') {
	$prefix = '';
	if ($stat == 'CZ') {
		$prefix = '+420';
	} elseif ($stat == 'SK') {
		$prefix = '+421';
		$s = preg_replace("~^0\s*([1-9])~", "$1", $s); // začínají číslo 0 někdy
	} elseif ($stat == 'DE') {
		$prefix = '+49';
	} elseif ($stat == 'AT') {
		$prefix = '+43';
	} elseif ($stat == 'FI') {
		$prefix = '+358';
	} elseif ($stat == 'PL') {
		$prefix = '+48';
	} elseif ($stat == 'FR') {
		$prefix = '+33';
	} elseif ($stat == 'RO') {
		$prefix = '+40';
	} elseif ($stat == 'CY') {
		$prefix = '+357';
	}
	
	$s = trim($s);
	$s = preg_replace('~\(\s*(0|1)\s*\)~', '', $s); // někdy tam je v závorce předvolba 0, tak to odebereme cele
	$s = preg_replace("~(^00)~", "+", $s);
	$s = preg_replace("~[^0-9\+]~", "", $s);
	
	if (!$s) return '';
	
	if (strpos($s, '+') === FALSE && $prefix != '')
	{
		$numPrefix = substr($prefix, 1);
		if ($numPrefix == substr($s, 0, strlen($numPrefix))) {
			$s = '+' . $s; // only plus was missing
		} else {
			if ($stat == 'AT') {
				if (strlen($s) > 10) {
					// odebereme počáteční nulu
					$s = preg_replace('~^0~', '', $s);
				}
			}
			
			$s = $prefix . $s;
		}
	}
	
	return $s;
}


/**
* Proměnné v JS/CSS souboru
*/
function zk123_handleTemplate($str)
{
	$places = '';
	if (zk123_getConfig('places_SK')) $places.= '|SK';
	if (zk123_getConfig('places_SK_BOX')) $places.= '|SK_BOX';
	if (zk123_getConfig('places_CZ')) $places.= '|CZ';
	if (zk123_getConfig('places_CZ_BOX')) $places.= '|CZ_BOX';
	
	$str = str_replace('{PLACES}', "'".trim($places, '|')."'", $str);
	
	$str = str_replace('{BIG_PACKAGES_ONLY}', zk123_getConfig('big_packages_only') ? 'true' : 'false', $str);
	
	return $str;
}


/**
* API REQUEST
*/
function zk123_request($methodUrl, $data = null)
{
	$username = zk123_getConfig('username');
	$password = zk123_getConfig('gpsw');
	$url = 'https://123kurier.jpsoftware.sk/' . $methodUrl;
	$ch = curl_init($url);
	curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: application/json']);
	curl_setopt($ch, CURLOPT_HEADER, 0);
	curl_setopt($ch, CURLOPT_USERPWD, ($username . ':' . $password));
	curl_setopt($ch, CURLOPT_TIMEOUT, 30);
	
	if (!isset($data)) {
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'GET');
		curl_setopt($ch, CURLOPT_POST, 0);
		curl_setopt($ch, CURLOPT_POSTFIELDS, null);
	} else {
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
		curl_setopt($ch, CURLOPT_POST, 1);
		curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
	}
	
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
	
	$result = curl_exec($ch);
	
	$code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
	curl_close($ch);
	if ($code !== 200) {
		$data = @json_decode($result);
		if ($data->exception && $data->code) {
			$err = var_export($data->exception, true);
			if (strpos($err, 'Wrong auth credentials.') !== false) {
				$err = 'Nesprávne prihlasovacie údaje.';
			}
			throw new Exception($err, $data->code);
		}
		else {
			$result = 'Neznámá chyba: '.$result;
			throw new Exception($result);
		}
	}
	return json_decode($result, true);
}


/**
* Pickup Point by Code
*/
function zk123_getPickupPoint($code)
{
	$points = zk123_request('atol-api/package');
	
	foreach ($points as $p)
	{
		if (strcasecmp($p['code'], $code) == 0)
		{
			return $p;
		}
	}
	return null;
}


/**
* Vrátí popis pobočky (administrace)
*/
function zk123_getPickupPointLabel($code, $withLink = false)
{
	if (!empty($code)) {
		$pobocka = zk123_getPickupPoint($code);
		if (!$pobocka) {
			$str = '<font style="color:red">neexistuje</font>';
		} else {
			$str = '';
			$str.= $pobocka['name'].' - '.$pobocka['city'].', '.$pobocka['street'];
			$pobocka['mapUrl'] = 'https://www.google.com/maps/search/'.urlencode($pobocka['street'].', '.$pobocka['city']);
			if ($withLink && $pobocka['mapUrl']) $str.= ' <a href="'.urldecode($pobocka['mapUrl']).'" target="_blank">(ukáž na mape)</a>';
		}
	}
	else {
		$str = '(žiadne)';
	}
	
	return $str;
}




/**
* Editace balíku v IS
*/
function zk123_editUrl($post_id) {
	
	return 'http://123kurier.jpsoftware.sk/atol/order/'; // prostě seznam objednávek
	
	$id = trim(get_post_meta($post_id, '_zk123_id', true));
	if (empty($id)) {
		return '#';
	} else {
		// tyhle údaje jsou celkem k ničemu, nedá se tam nic změnit a není tam ani smazání, a není tam ani jít zpět!
		return 'http://123kurier.jpsoftware.sk/atol/order/edit/'.$id;
	}
}

/**
* Stav zásilky
*/
function zk123_historyUrl($post_id) {
	$id = trim(get_post_meta($post_id, '_zk123_id', true));
	if (empty($id)) {
		return '#';
	} else {
		return 'http://123kurier.jpsoftware.sk/atol/order-history/?orderId='.$id;
	}
}



/**
* Vrátí sledovací čísla
*/
function zk123_getTrackingCodes($post_id)
{
	$trackingCodes = trim(get_post_meta($post_id, '_zk123_tracking_code', true));
	
	$trackingCodes = $trackingCodes ? explode(";", $trackingCodes) : array(); 
	
	return $trackingCodes;
}


/**
* Vrátí LINK pro sledování
*/
function zk123_trackingLink($mixed)
{
	if (is_array($mixed))
		$mixed = current($mixed);
	else 
		$mixed = current(explode(';', $mixed));
	
	return 'http://123kurier.jpsoftware.sk/sledovanie-zasielky?number='.urlencode($mixed);
}



/**
* Match proměnných z konfigurace: shipping_regexp, cod_regexp
*/
function zk123_match($test, $configVarName)
{
	$strList = zk123_getConfig($configVarName);
	if ($strList == '') return true;
	
	$list = preg_split('~\s*[,;]\s*~', $strList); // oddělené čárkama
	
	foreach ($list as $s) {
		if (stripos($test, $s) !== false) return true;
	}
	return false;
}
		

/**
* Zda jde o 123kuriér zásilku
* @param (mixed) - (string) shippingMethod / (int) postId
*/
function zk123_is($mixed)
{
	if (is_numeric($mixed)) {
		$ord = wc_get_order($mixed);
		$dop = '';
		if (!empty($ord)) {
			foreach ($ord->get_shipping_methods() as $m) {
				$dop.= $m['name'].'<br>';
			}
		}
	} else {
		$dop = $mixed;
	}
	return zk123_match($dop, 'shipping_regexp');
}


/**
* Zda je dobírka
* @param (mixed) - (string) paymentMethod / (int) postId
*/
function zk123_isCOD($mixed)
{
	if (is_numeric($mixed)) {
		$ord = wc_get_order($mixed);
		$pla = $ord->get_payment_method_title();
	} else {
		$pla = $mixed;
	}
	return zk123_match($pla, 'cod_regexp');
}



/**
* VRÁTÍ NASTAVENÍ KONFIGURACE
*/
function zk123_getConfig($k = null, $ifNull = null) {
	static $data;
	if (!isset($data)) {
		$data = (object) array();
		$file = '';
		if (file_exists(__DIR__.'/.config_json')) $file = __DIR__.'/.config_json';
		elseif (file_exists(__DIR__.'/.config_json_default')) $file = __DIR__.'/.config_json_default';
		if ($file) {
			$content = file_get_contents($file);
			$data = json_decode($content);
		}
		if (!empty($data->iban)) {
			if (!preg_match('~[0-9]~', $data->iban)) $data->iban = ''; // není tam žádné číslo
		}
	}
	if ($k) {
		$v =  isset($data->$k) ? $data->$k : $ifNull;
		return $v;
	}
	else {
		return $data;
	}
}
/**
* Uloží konfiguraci
*/
function zk123_setConfig($k, $v) {
	$data = zk123_getConfig();
	if (!isset($v)) {
		unset($data->$k);
	}
	elseif (isset($data->$k) && $data->$k === $v) {
		// žádná změna
		return false;
	}
	else {
		$data->$k = $v;
	}
	// uložíme
	return file_put_contents(__DIR__.'/.config_json', json_encode($data));
}


} // konec functions
