<?php
/**
* Plugin Name: WooCommerce 123kurier.sk
* Plugin URI: https://www.123kurier.sk/?plugin
* Description: Plugin pre správu balíkov prepravnej služby 123KURIÉR
* Version: 9.0
* Author: 123kurier.sk
* Author URI: https://www.123kurier.sk
* Text Domain:  123kurier
*
* WC requires at least: 4.4
* WC tested up to: 5.2.1
*
* Potřebuje: PHP 5.3.0+
*
* Používáné META tagy v objednávce:
* _zk123_tracking_code - Sledovací číslo balíku, oddělené středníkem pokud více
* _zk123_id - ID order
* _zk123_pickup_order (bool) - Zda byl pro balík objednán svoz
* _zk123_pickup_date (Y-m-d) - Datum, kdy se balík importoval
* _zk123_packages_weight - Seznam hmotností v Kg odděleno +, pokud více zásilek
* _zk123_driver_note - Poznámka řidiči
* _zk123_shippingPickup_code - Vybraný kód pobočky
*/


 
if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly



include_once __DIR__.'/functions.php';



//---------------- DETAIL OBJEDNÁVKY - META BOX

function zk123_add_custom_box() {
	global $post;
	if (!zk123_is($post->ID)) return; // nejedná se o 123KURIÉR objednávku
	
	add_meta_box(
		'zk123_box',           // Unique ID
		'123KURIÉR',  // Box title
		'zk123_box_html',  // Content callback, must be of type callable
		'shop_order'                  // Post type
	);
}
add_action('add_meta_boxes', 'zk123_add_custom_box');



/**
* STORNO ZÁSILKY ----------->>> TY HOOKS PRO NOTICES NEJSOU ÚPLNĚ IDEÁLNÍ PODLE MĚ
*/
function zk123_saved_order_items($post_id) // při uložení objednávky
{
	if (!empty($_POST['zk123_cancel']))
	{
		$notices = zk123_deleteShipment($post_id);
		
		update_option('zk123_notices', $notices);
	}
}
add_action('woocommerce_saved_order_items', 'zk123_saved_order_items');


function zk123_delete_order($post_id) // v případě smazání objednávky
{
	zk123_deleteShipment($post_id);
}
add_action('woocommerce_delete_order', 'zk123_delete_order');

		
		
function zk123_deleteShipment($post_id)
{
	$ord = wc_get_order($post_id);
	
	$trackingCodes = zk123_getTrackingCodes($post_id);
	
	if (empty($trackingCodes)) return; // není co mazat
	
	$deleted = true;
	$notices = '';
	
	// ZÁSILKU NELZE STORNOVAT PŘES API
	$notices.= '<div class="notice notice-error is-dismissible"><p><b>Podacie čislo bolo z objednávky vymazané. Zásielku č. '.implode(", ", $trackingCodes).' je potrebné stornovať v <a href="'.zk123_editUrl($post_id).'" target="_blank">informačnom systéme 123kuriér</a>.</b></p><script>window.open(\''.zk123_editUrl($post_id).'\')</script></div>';


	// zrušíme META TAGY
	delete_post_meta($post_id, '_zk123_tracking_code');
	delete_post_meta($post_id, '__date');
	delete_post_meta($post_id, '_zk123_pickup_order');
	
	// přidáme poznámku k objednávce
	$message = sprintf( __( 'Stornované zásielky č. '.implode(", ", $trackingCodes), 'my-textdomain' ), wp_get_current_user()->display_name);
	$ord->add_order_note( $message );
	
	return $notices;
}


/**
* ADMIN NOTICES -- toto není optimální, ale nemůžu dohledat jak to udělat 100%
*/
function zk123_admin_notice() {
	$notices = get_option('zk123_notices');
	if (!empty($notices)) {
		echo $notices;
		delete_option('zk123_notices');
	}
}
add_action('admin_notices', 'zk123_admin_notice');




/**
* PANEL v detailu objednávky
*/
function zk123_box_html($post)
{
	$post_id = $post->ID;
    $pickupDate = get_post_meta($post_id, '_zk123_pickup_date', true);
	
	$dir = plugins_url('123kurier');
	
	echo '<style>
.zk123panel{display: flex;  text-align: center;    margin: auto;}
.zk123panel .button {display: flex;line-height: 1.5;white-space: pre-wrap;justify-content: center;height: auto;max-height: initial;align-content: center; align-items: center;}
.zk123panel .button+.button { margin-left: 5px; }
.zk123panel-rows { margin: 12px 1px 0 1px;}
.zk123panel-rows>A.label{ cursor:pointer; }
.zk123panel-rows>.label { text-decoration:none; color:#000; display: flex; cursor: default; flex: 1; border-bottom: 1px solid #ddd; width: 100%; box-sizing: border-box; border-radius: 3px; padding: 8px 0; align-items: center; }
.zk123panel-rows>.label>SPAN:first-child { flex-grow: 0; flex-shrink: 1; }
.zk123panel-rows>.label>SPAN:last-child { padding-left: 8px; }
.zk123panel-rows .label:last-child { border-bottom: 0; }
</style>';	
	
	$codes = zk123_getTrackingCodes($post_id);
	$trackingCodes = implode(";", $codes);
	
	$wasImported = count($codes) > 0;
	
	echo '<div data-zk123-ajaxable="mainbox">'; //--- ajaxable obsah
	
	// KONTROLNÍ PANEL
	echo '<div class="zk123panel">';
	if ($wasImported) {
		// ZÁSILKA BYLA IMPORTOVÁNA
		echo '<a href="'.$dir.'/popup.php?action=labels&codes='.urlencode($trackingCodes).'" onclick="var pos=prompt(\'Pozícia etikety? (1-4)\', 1);if(pos!==null) zk123_popWin(this.href+\'&pos=\'+pos);return false;" class="button" style="width:10%;min-width:80px">Tlač štítku</a>';
		echo '<a href="'.$dir.'/popup.php?action=pickuplist&pickup_date='.urlencode($pickupDate).'" onclick="zk123_popWin(this.href);return false;" class="button">Podací hárok '.date('d.m.Y', strtotime($pickupDate)).'</a>';
		echo '<button type="submit" name="zk123_cancel" value="1" onclick="if(!confirm(\'POZOR! Zásielku je nutné stornovať v systéme 123kurier.sk\nTýmto iba odstránite podacie číslo u tejto objednávky, aby ste mohli vykonať opätovný import. Pokračovať?\')) return false;" class="button" style="width:10%;min-width:70px">Stornovať zásielku</button>';
	}
	else {
		echo '<a href="'.$dir.'/popup.php?action=import&post_ids='.$post_id.'" onclick="var pos=prompt(\'Pozícia etikety? (1-4)\', 1);if(pos!==null) zk123_popWin(this.href+\'&pos=\'+pos);return false;" class="button">Importovať do 123KURIÉR a tlač štítku</a>';
		// echo '<a href="'.$dir.'/popup.php?action=create_pickup" onclick="zk123_popWin(this.href);return false;" class="button">Objednat svoz</a>';		
	}
	echo '</div>';
	
	
	
	echo '<div class="zk123panel-rows" id="post-'.$post_id.'">'; // potřebujeme ID kvůli JS ukládání
	
	if ($wasImported) {
		$url = zk123_trackingLink($codes);
		
		echo '<label class="label">';
		if (count($codes) > 1) {
			$str = 'Číslo zásielok';
		} else {
			$str = 'Číslo zásielky';
		}
		echo '<span>'.$str.':</span><span><a href="'.$url.'" target="_blank">'.implode(", ", $codes).'</a></span>';
		echo '</label>';
	}
	
	
	$defaultWeight = zk123_getConfig('default_weight');
	$hasDefaultWeight = true;
	if (!is_numeric($defaultWeight)) {
		$defaultWeight = '0';
		$hasDefaultWeight = false;
	}
	
	
	$weight = get_post_meta($post->ID, '_zk123_packages_weight', true);
	echo '<label class="label">';
	$weights = $weight ? explode("+", $weight) : [];
	$str = 'Zadané hmotnosti';
	echo '<span>'.$str.':</span>';
	echo '<span>';
	if ($wasImported) {
		echo '<b>'.implode(" + ", $weights).' kg</b>';
	} else {
		echo ' ';
		// ukládáme přes AJAX (onblur event)
		// potřebujeme znát hmotnosti (potažmo počet balíků)
		$weights = get_post_meta($post_id, '_zk123_packages_weight', true);
		echo '<input type="text" data-name="zk123_packages_weight" class="tips" data-tip="U viac balíkov píšte viac hmotnosťou 1 + 5 + 2 alebo 2,5 a 2"';
		echo ' value="'.esc_attr($weights).'" placeholder="'.$defaultWeight.'" style="width:65px;';
		if ($weights == '' && !$hasDefaultWeight) echo 'background:#ffeded;'; // @note: nutno změnit taky v JS
		echo '"> kg';
	}
	echo'</span>';
	echo '</label>';
	
	
	// _zk123_driver_note
	echo '<label class="label">';
	echo '<span>Poznámka vodiči:</span><span>';
	$note = get_post_meta($post_id, '_zk123_driver_note', true);
	if ($wasImported)  {
		echo $note ? $note : '<b>ne</b>';
	} else {
		echo '<button type="button" class="button tips zk123_driver_note" data-tip="Poznámka vodiči" data-value="'.esc_attr($note).'">';
		echo '<i class="fa'.(empty($note) ? 'r' : '').' fa-sticky-note"></i>'; // @note: nutno i v JS
		echo '</button>';
	}	
	echo '</span>';
	echo '</label>';
	
	//-------------------- VYBRANÁ POBOČKA
	if ($wasImported) {
		echo '<label class="label">';
	} else {
		echo '<a href="'.$dir.'/popup.php?action=pickuppoint&post_id='.$post_id.'" onclick="zk123_popWin(this.href);return false;" class="label">';
	}
	echo '<span>Balíkové Centrum:</span>';
	$code = get_post_meta($post_id, '_zk123_shippingPickup_code', true);
	echo '<span id="zk123_pobocka_code">';
	$str = zk123_getPickupPointLabel($code);
	echo $str ?: $code;
	echo '</span>';
	if ($wasImported) {
		echo '</label>';
	} else {
		echo '</a>';
	}
	
	
	echo '</div>';
	
	
	echo '</div>'; //--- konec ajaxable
}



/**
* TOHLE PŘIDÁME DO DETAILŮ OBJEDNÁVKY
*/
function zk123_after_customer($wc_order)
{
	$post_id = $wc_order->get_id();
	
	// PŘIDÁME INFORMACE O PICKUP POINT
	$code = get_post_meta($post_id, '_zk123_shippingPickup_code', true);
	if ($code) {
		echo '<h2 class="woocommerce-column__title">Doručenie na Balíkové Centrum:</h2>';
		echo '<p>'.zk123_getPickupPointLabel($code, true).'</p>';
	}
	
	$trackingCodes = zk123_getTrackingCodes($post_id);
	if ($trackingCodes)
	{
		// PŘIDÁME SLEDOVACÍ ČÍSLO
		echo '<h2 class="woocommerce-column__title">Číslo pre sledovanie zásielky</h2>';
		echo '<p>Zásielka č. <a href="'.zk123_trackingLink($trackingCodes).'"> (123KURIÉR)';
		echo implode(", ", $trackingCodes);
		echo '</a>';
	}
}

// u konce objednávky (checkout)
add_action('woocommerce_order_details_before_order_table', 'zk123_after_customer');

// email s novou objednávkou
add_action('woocommerce_email_customer_details', 'zk123_after_customer');





/**
* SLOUPEC "123KURIÉR" V OBJEDNÁVKÁCH
*/
function zk123_columns( $columns )
{
	if (!is_array($columns)) {
		$columns = (array) $columns;
	}
	
	$mykA = 'order_zk123_shipping';
	$myvA = 'Doprava';
	
	$myk = 'order_zk123 no-link';
	$myv = '123KURIÉR';
	
	$newcolumns = array();
	foreach ($columns as $k => $v)
	{
		if ($k == 'order_total' && !isset($newcolumns[$myk])) {
			// vložíme před
			$newcolumns[$mykA] = $myvA;
			$newcolumns[$myk] = $myv;
			unset($mykA);
		}
		
		$newcolumns[$k] = $v;
	}
	
	if (isset($mykA)) {
		// no tak vložíme nakonec
		$newcolumns[$mykA] = $myvA;
		$newcolumns[$myk] = $myv;
	}
	
	return $newcolumns;	
}
add_filter('manage_edit-shop_order_columns', 'zk123_columns');



/**
* OBSAH SLOUPCE
*/
function zk123_column_values($column)
{
	global $post;
	$post_id = $post->ID;
	
	if ($column == 'order_zk123_shipping')
	{
		$ord = wc_get_order($post_id);
		$dop = '';
		foreach ($ord->get_shipping_methods() as $m) {
			$dop.= $m['name'].'<br>';
		}
		echo $dop ? $dop : '&ndash;';
	}
	elseif ( $column == 'order_zk123 no-link' )
	{
		
		$ord = wc_get_order($post_id);
		$dop = '';
		foreach ($ord->get_shipping_methods() as $m) {
			$dop.= $m['name'].'<br>';
		}
		
		if (zk123_is($dop))
		{
			echo '<span data-zk123-ajaxable="'.$post_id.'">'; // tohle se bude obnovovat při onfocus/onblur
			
			$codes = zk123_getTrackingCodes($post_id);
				
			if ($codes)
			{
				// bylo importováno
				$pickupDate = get_post_meta($post_id, '_zk123_pickup_date', true);
				
				$dir = plugins_url('123kurier');
				
				$weights = get_post_meta($post_id, '_zk123_packages_weight', $single = true);
				$podbaliku = count(explode("+", $weights));
				echo '<a href="'.zk123_historyUrl($post_id).'" target="_blank" title="Odkaz pre detail">'.implode(", ", $codes).'</a>';
				if ($podbaliku > 1) echo " ($podbaliku)";
				echo ' &nbsp; <a href="'.$dir.'/popup.php?action=pickuplist&pickup_date='.urlencode($pickupDate).'" onclick="zk123_popWin(this.href);return false;" class="button" title="Podací hárok" style="vertical-align:baseline;">'.date("d.m.Y", strtotime($pickupDate)).'</a>';
			}
			else {
				// poznámka řidiči
				$note = get_post_meta($post_id, '_zk123_driver_note', $single = true);
				echo '<button type="button" class="button tips zk123_driver_note" data-tip="Poznámka vodiči" data-value="'.esc_attr($note).'" style="vertical-align:baseline;">'; // styl pro starší verze
				echo '<i class="fa'.(empty($note) ? 'r' : '').' fa-sticky-note"></i>'; // @note: nutno i v JS
				echo '</button>';
				
				$defaultWeight = zk123_getConfig('default_weight');
				$hasDefaultWeight = true;
				if (!is_numeric($defaultWeight)) {
					$defaultWeight = '0';
					$hasDefaultWeight = false;
				}
				
				
				echo ' ';
				// ukládáme přes AJAX (onblur event)
				// potřebujeme znát hmotnosti (potažmo počet balíků)
				$weights = get_post_meta($post_id, '_zk123_packages_weight', $single = true);
				echo '<input type="text" data-name="zk123_packages_weight" class="tips" data-tip="HMOTNOSŤ (Kg) - U viac balíkov píšte viac hmotnosťou 1 + 5 + 2 alebo 2,5 a 2"';
				echo ' value="'.esc_attr($weights).'" placeholder="'.$defaultWeight.'" style="width:60px;';
				if ($weights == '' && !$hasDefaultWeight) echo 'background:#ffeded;'; // @note: nutno změnit taky v JS
				echo '">';
			}
			
			echo '</span>';
		}
		else {
			echo $dop ? $dop : '&ndash;';
		}
	}
}
add_action('manage_shop_order_posts_custom_column', 'zk123_column_values', 2);



function zk123_admin_head($x) {
	if (mb_strpos(ob_get_contents(), 'fontawesome') !== false) return; // už to někdo inkludoval
	echo '<link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.8.2/css/all.css" integrity="sha384-oS3vJWv+0UjzBfQzYUhtDYW+Pj2yciDJxpsK1OYPAYjqT085Qq/1cq5FLXAZQ7Ay" crossorigin="anonymous">';
}
add_action('admin_head', 'zk123_admin_head');




/**
* Přidáme BULK ACTIONS do výpisu objednávek + JS POUŽÍVÁM V DETAILU OBJ.
*/
function zk123_admin_footer() {
	// @note: strkám to takto přes JS, kvůli následnému otevírání v novém okně + OPTGROUP
	global $pagenow, $typenow;
	
	if ($pagenow == 'plugins.php');
	elseif ($typenow != 'shop_order') return;
	
	$dir = plugins_url('123kurier');
	
    echo '<script type="text/javascript">';
	echo "var ZK123_PLUGIN_URL = '$dir';";
	echo '</script>';
	echo '<script type="text/javascript" src="'.$dir.'/123kurier.js?'.filemtime(__DIR__.'/123kurier.js').'" charset="UTF-8"></script>';
}
add_action('admin_footer', 'zk123_admin_footer');



/**
* SEZNAM PLUGINŮ
*/
add_filter( 'plugin_row_meta', 'zk123_plugin_fw_row_meta', 20, 4 );

if (!function_exists('zk123_plugin_fw_row_meta')) {
	/**
	* V seznamu pluginů doplníme odkaz pro NASTAVENÍ
	*/
	function zk123_plugin_fw_row_meta($plugin_meta, $plugin_file, $plugin_data, $status)
	{
		if  (mb_strpos($plugin_file, '123kurier') === false) return $plugin_meta;
		
		$url = '?plugin'; // identifikace v headeru -- viz. hlavička tohoto souboru
		
		$dir = plugins_url('123kurier');
		
		$plugin_meta = preg_replace('~<a([^>]+)'.$url.'([^>]+)>[^<]+</a>~i', '
			<a href="https://www.123kurier.sk">Navštíviť web pluginu</a> |
			<a href="https://www.123kurier.sk/kontakt/" target="_blank"><span class="dashicons dashicons-admin-users"></span> Podpora / Kontakt</a> |
			<a href="'.$dir.'/popup.php?action=configuration" onclick="zk123_popWin(this.href);return false;"><span class="dashicons dashicons-admin-generic"></span> Konfigurácia pluginu</a>',
			$plugin_meta);
		
		return $plugin_meta;
	}
}




/**
* TOTO DOPLNÍ TYP DOPRAVY
*/
function zk123_addshmet() {

    if ( ! class_exists( 'WC_zk123_shmet' ) ) {
        class WC_zk123_shmet extends WC_Shipping_Method {

            public function __construct( $instance_id = 0) {
                $this->id = 'zk123_shipping';
                $this->instance_id = absint( $instance_id );
                
				$this->domain = 'zk123';
				
                $this->method_title = __('123kuriér', $this->domain );
                $this->method_description =  __('', $this->domain );
                $this->supports = array(
                    'shipping-zones',
                    'instance-settings',
                    'instance-settings-modal',
                );
 
                $this->init();
				$this->enabled = "yes";
            }

            function init() {
                $this->init_form_fields();
                $this->init_settings();
                $this->enabled = $this->get_option( 'enabled', $this->domain );
                $this->title   = $this->get_option( 'title', $this->domain );
                $this->info    = $this->get_option( 'info', $this->domain );
                $this->cost    = $this->get_option( 'cost', $this->domain );
                add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
             }

            function init_form_fields() {
                $this->instance_form_fields = array(
                    'title' => array(
                        'type'          => 'text',
                        'title'         => __('Názov', $this->domain),
                        //'description'   => __('Title to be displayed on site.', $this->domain ),
                        'default'       => __('123kuriér', $this->domain ),
                    ),
                    'cost' => array(
                        'type'          => 'text',
                        'title'         => __('Cena', $this->domain),
                        //'description'   => __('Enter a cost', $this->domain ),
                        'default'       => 0,
                    ),
                );
            }

			/** bez téhle funkce se neukazuje v košíku
			*/
            public function calculate_shipping( $packages = array() ) {
                $rate = array(
                    'id'       => $this->id,
                    'label'    => $this->title,
                    'cost'     => $this->cost,
					'calc_tax' => 'per_item'
                );
                $this->add_rate($rate);
            }
        }
    }
	
	
    if ( ! class_exists( 'WC_zk123_shmetPickup' ) ) {
        class WC_zk123_shmetPickup extends WC_Shipping_Method {

            public function __construct( $instance_id = 0) {
                $this->id = 'zk123_shippingPickup';
                $this->instance_id = absint( $instance_id );
                
				$this->domain = 'zk123';
				
                $this->method_title = __('123kuriér - Balíkové Centrum', $this->domain );
                $this->method_description =  __('', $this->domain );
                $this->supports = array(
                    'shipping-zones',
                    'instance-settings',
                    'instance-settings-modal',
                );
 
                $this->init();
				$this->enabled = "yes";
            }

            function init() {
                $this->init_form_fields();
                $this->init_settings();
                $this->enabled = $this->get_option( 'enabled', $this->domain );
                $this->title   = $this->get_option( 'title', $this->domain );
                $this->info    = $this->get_option( 'info', $this->domain );
                $this->cost    = $this->get_option( 'cost', $this->domain );
                add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
             }

            function init_form_fields() {
                $this->instance_form_fields = array(
                    'title' => array(
                        'type'          => 'text',
                        'title'         => __('Názov', $this->domain),
                        //'description'   => __('Title to be displayed on site.', $this->domain ),
                        'default'       => __('123kuriér - Balíkové Centrum', $this->domain ),
                    ),
                    'cost' => array(
                        'type'          => 'text',
                        'title'         => __('Cena', $this->domain),
                        //'description'   => __('Enter a cost', $this->domain ),
                        'default'       => 0,
                    ),
                );
            }

			/** bez téhle funkce se neukazuje v košíku
			*/
            public function calculate_shipping( $packages = array() ) {
                $rate = array(
                    'id'       => $this->id,
                    'label'    => $this->title,
                    'cost'     => $this->cost,
					'calc_tax' => 'per_item'
                );
                $this->add_rate( $rate );
            }
        }
    }
}
add_action('woocommerce_shipping_init', 'zk123_addshmet');

function zk123_addsh( $methods ) {
    $methods['zk123_shipping'] = 'WC_zk123_shmet';
    $methods['zk123_shippingPickup'] = 'WC_zk123_shmetPickup';
    return $methods;
}
add_filter('woocommerce_shipping_methods', 'zk123_addsh');



/**
* Zda jde o pickup dopravu
*/
function zk123_isShippingPickup($method_id = null)
{
	if (!isset($method_id)) {
		// aktuálně zvolená doprava
		$method_id = current(WC()->session->get('chosen_shipping_methods'));
	}
	
	if (preg_match('~zk123_shippingPickup~', $method_id)) return true;
	
	// kompatibilita pro Flexible Shipping Single
	$ident = 'woocommerce_'.str_replace(':', '_', $method_id).'_settings';
	$opt = get_option($ident);
	if ($opt && isset($opt['method_title'])) {
		if (preg_match('~(123kuri[eé]r)~iu', $opt['method_title']) && preg_match('~(V[ýy]dajn[ée] miest|Bal[íi]kov[ée] Centrum)~iu', $opt['method_title'])) {
			return true;
		}
	}
	
	return false;
}



function zk123_shippingPickup_selector($method, $index)
{
	if( is_cart() ) return; // Exit on cart page
	
	$cur_method_id = current(WC()->session->get('chosen_shipping_methods'));
	
	if ($method->id == $cur_method_id && zk123_isShippingPickup())
	{
		$code = '';
		$label = '';
		// předzvolené výdejní místo
		$k = '_zk123_shippingPickup_code';
		if (!empty($_POST[$k])) {
			$code = $_POST[$k];
			$p = zk123_getPickupPoint($code);
			$label = $p['name'];
		}
		echo '<div id="zk123_shippingPickup_selector">';
		echo '<a href="#zk123_pickup" data-code="'.$code.'" data-label="'.$label.'">';
		woocommerce_form_field($k,
			array(
				'type' => 'hidden',
				'required' => true,
			),
			$code
		);
		echo '</a>';
		echo '</div>';
	}
}
add_filter('woocommerce_after_shipping_rate', 'zk123_shippingPickup_selector', 10, 2);



// Field validation, as this packing field is required
add_action('woocommerce_checkout_process', 'zk123_checkout_process');
function zk123_checkout_process()
{
	if (zk123_isShippingPickup())
	{
		$k = '_zk123_shippingPickup_code';
		if (isset($_POST[$k]) && empty($_POST[$k]))
		{
			wc_add_notice( __( "Prosím zvoľte Balíkové Centrum!", "woocommerce" ), 'error' );
		}
	}
}

function zk123_create_order($order, $data)
{
	if (zk123_isShippingPickup())
	{
		$k = '_zk123_shippingPickup_code';
		if (isset($_POST[$k])) {
			$v = $_POST[$k];
			if (!empty($v)) $order->update_meta_data($k, $v);
		}
	}
}
add_action('woocommerce_checkout_create_order', 'zk123_create_order', 20, 2);




/**
* JS/CSS PRO VÝBĚR VÝDEJNÍHO MÍSTA V KOŠÍKU
*/
function zk123_checkout_top()
{
	// dávám to takto nahoru, protože REVIEW_ORDER blok se aktualizuje ajaxem a pak by se to spoštělo vícekrát!!!
	static $called;
	if (isset($called)) return;
	$called = 1;
	
	echo '<script type="text/javascript" charset="UTF-8" data-src="123kurier_pickup.js">';
	echo zk123_handleTemplate(@file_get_contents(__DIR__.'/123kurier_pickup.js'));
	echo '</script>';
	echo '<style data-src="123kurier_pickup.css">';
	echo @file_get_contents(__DIR__.'/123kurier_pickup.css');
	echo '</style>';
}

add_filter('woocommerce_before_checkout_form', 'zk123_checkout_top');
add_filter('woocommerce_after_cart', 'zk123_checkout_top');
